import request from '@/utils/request'

/**
 * 颜选美学小程序订单列表
    orderId: '',
    orderNo: '', //  订单编号
    buyer: '', //  买家
    receiver: '', //  收货人
    productName: '', //  商品名称
    status: '', // 订单状态 0待确认,11待收待发,12待收部发,13待收全发,21部收待发,22部收部发,23部收全发,1已收待发,32已收部发,33已收全发,4交易完成,5订单完成,6已关闭,7交易全退
    receiptStatus: '', //  收款状态 1待收款、2部分收款、3已收款
    collageStatus: '', //  拼团状态 1拼团中 2已拼成
    sendOutStatus: '', //  发货状态：1待发货、2部分发货、3已发货
    payStatus: '', //  付款状态：1待付款、2部分付款、3已付款
    refundType: '', //  退款状态：0无退款，1有退款
    userId: '', //  分销者
    startTime: '',
    endTime: ''
 * @returns
 */
export function getHeHeOrderList(params) {
  return request({
    url: '/HeHe/order/list',
    method: 'get',
    params
  })
}
/**
 * 颜选美学退款单列表
 * @param {*} returnedNo, 退款编号
 * @param {*} shopOrderId 订单ID
 * @param {*} shopOrderNo 订单编号
 * @param {*} name 买家
 * @param {*} beginTime 申请开始时间
 * @param {*} endTime 申请结束时间
 * @param {*} status 退款审核状态 1待审核、2审核通过、3审核不通过
 * @param {*} pageNum, 页码
 * @param {*} pageSize 页数
 * @returns
 */
export function returnedPurchaseList(params) {
  return request({
    url: '/HeHe/returnedPurchase/list',
    method: 'get',
    params
  })
}
/**
 * 颜选美学小程序分享减免活动列表
 * @param {*} name,
 * @param {*} status 状态：1待上架，2已上架，3已下架,
 * @param {*} pageNum,
 * @param {*} pageSize
 * @returns
 */
export function getHeHeReduction(params) {
  return request({
    url: '/HeHe/reduction/list',
    method: 'get',
    params
  })
}
/**
 * 颜选美学小程序首内部优惠
 * @param {*} pageNum,
 * @param {*} pageSize
 * @returns
 */
export function getHeHeInsideDiscount(params) {
  return request({
    url: '/HeHe/inside/discount',
    method: 'get',
    params
  })
}
/**
 * 颜选美学小程序商品分类管理
 * @param {*} pageNum,
 * @param {*} pageSize
 * @returns
 */
export function getHeHeProductBigType(params) {
  return request({
    url: '/HeHe/product/bigType',
    method: 'get',
    params
  })
}
/**
 * 颜选美学小程序商品管理列表
 * @param {*} productId 商品id,
 * @param {*} name 商品名称,
 * @param {*} shopName 供应商名称,
 * @param {*} validFlag 上架状态:1上架,2下架,
 * @param {*} includedTax 是否含税 0不含税，1含税,
 * @param {*} invoiceType 发票类型(基于是否含税基础) 1增值税专用发票，2增值税普通发票, 3不能开票,
 * @param {*} pageNum,
 * @param {*} pageSize
 * @returns
 */
export function getHeHeProductList(params) {
  return request({
    url: '/HeHe/product/list',
    method: 'get',
    params
  })
}
/**
 * 颜选美学小程序拼团商品列表
 * @param {*} id 商品id,
 * @param {*} productName 商品名称,
 * @param {*} shopName 供应商名称,
 * @param {*} status 上架状态:1上架,0下架,
 * @param {*} pageNum,
 * @param {*} pageSize
 * @returns
 */
export function getHeHeCollageProduct(params) {
  return request({
    url: '/HeHe/collage/product',
    method: 'get',
    params
  })
}
/**
 * 颜选美学小程序拼团记录列表
 * @param {*} id 商品id,
 * @param {*} productName 商品名称,
 * @param {*} shopName 供应商名称,
 * @param {*} status 拼团状态:1拼团中,2已拼团,
 * @param {*} pageNum,
 * @param {*} pageSize
 * @returns
 */
export function getHeHeCollageRecord(params) {
  return request({
    url: '/HeHe/collage/record',
    method: 'get',
    params
  })
}
